@@ -52,10 +52,11 @@ dcc_window_class_init (DccWindowClass *klass)
 static void
 transfer_selection_changed (GtkTreeSelection *selection, DccWindow *window)
 {
-	if (gtk_tree_selection_get_selected (selection, NULL, NULL))
+	if (gtk_tree_selection_get_selected (selection, NULL, NULL)) {
 		gtk_widget_set_sensitive (window->stop_button, TRUE);
-	else
+	} else {
 		gtk_widget_set_sensitive (window->stop_button, FALSE);
+	}
 }
 
 static void
@@ -67,8 +68,9 @@ transfer_stop_clicked (GtkButton *button, DccWindow *window)
 	struct DCC *dcc;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->transfer_list));
-	if (gtk_tree_selection_get_selected (selection, &model, &iter) == FALSE)
+	if (gtk_tree_selection_get_selected (selection, &model, &iter) == FALSE) {
 		return;
+	}
 
 	gtk_tree_model_get (model, &iter, DCC_COLUMN, &dcc, -1);
 	gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
@@ -80,14 +82,15 @@ dcc_window_init (DccWindow *window)
 {
 	GladeXML *xml;
 	GtkTreeSelection *selection;
+	gchar *path;
 
 	xml = NULL;
-	if (g_file_test ("../../data/dcc-window.glade", G_FILE_TEST_EXISTS))
-		xml = glade_xml_new ("../../data/dcc-window.glade", "toplevel", NULL);
-	if (!xml)
-		xml = glade_xml_new (XCHATSHAREDIR "/dcc-window.glade", "toplevel", NULL);
-	if (!xml)
+	path = locate_data_file ("dcc-window.glade");
+	xml = glade_xml_new (path, "toplevel", NULL);
+	g_free (path);
+	if (!xml) {
 		return;
+	}
 
 #define GW(name) ((window->name) = glade_xml_get_widget (xml, #name))
 	GW(transfer_list);
@@ -154,13 +157,14 @@ dcc_window_init (DccWindow *window)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (window->transfer_list), window->info_column);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (window->transfer_list), window->remaining_column);
 
-	if (g_file_test ("../../data/stock_up.png", G_FILE_TEST_EXISTS)) {
-		window->up_icon   = gdk_pixbuf_new_from_file_at_size ("../../data/stock_up.png",   24, 24, NULL);
-		window->down_icon = gdk_pixbuf_new_from_file_at_size ("../../data/stock_down.png", 24, 24, NULL);
-	} else {
-		window->up_icon   = gdk_pixbuf_new_from_file_at_size (XCHATSHAREDIR "/stock_up.png",   24, 24, NULL);
-		window->down_icon = gdk_pixbuf_new_from_file_at_size (XCHATSHAREDIR "/stock_down.png", 24, 24, NULL);
-	}
+	/* FIXME: why do these not use the icon theme? */
+	path = locate_data_file ("stock_up.png");
+	window->up_icon = gdk_pixbuf_new_from_file_at_size (path, 24, 24, NULL);
+	g_free (path);
+
+	path = locate_data_file ("stock_down.png");
+	window->down_icon = gdk_pixbuf_new_from_file_at_size (path, 24, 24, NULL);
+	g_free (path);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->transfer_list));
 	g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (transfer_selection_changed), window);
@@ -267,8 +271,9 @@ dcc_window_update (DccWindow *window, struct DCC *dcc)
 	GtkTreeIter iter;
 
 	/* DCC chats cause crashes here, because they're not handled in this window. */
-	if (dcc->type == 2)
+	if (dcc->type == 2) {
 		return;
+	}
 
 	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (window->transfer_store), &iter)) {
 		do {
@@ -321,11 +326,11 @@ dcc_window_update (DccWindow *window, struct DCC *dcc)
 				}
 
 				gtk_list_store_set (window->transfer_store, &iter,
-						    INFO_COLUMN, info_text,
-						    DONE_COLUMN, done,
-						    DONE_LABEL_COLUMN, done_text,
-						    TIME_COLUMN, remaining_text,
-						    -1);
+				                    INFO_COLUMN, info_text,
+				                    DONE_COLUMN, done,
+				                    DONE_LABEL_COLUMN, done_text,
+				                    TIME_COLUMN, remaining_text,
+				                    -1);
 				g_free (done_text);
 				g_free (info_text);
 				g_free (remaining_text);
@@ -342,8 +347,9 @@ dcc_window_update (DccWindow *window, struct DCC *dcc)
 					gpointer image_data;
 
 					/* If the file doesn't exist yet, don't do the icon */
-					if (g_file_test (dcc->destfile, G_FILE_TEST_EXISTS) == FALSE)
+					if (g_file_test (dcc->destfile, G_FILE_TEST_EXISTS) == FALSE) {
 						return;
+					}
 
 					/* Get MIME type from gnome-vfs, create the proper file icon for it. */
 					mime = gnome_vfs_get_mime_type (dcc->destfile);
@@ -371,10 +377,11 @@ dcc_window_update (DccWindow *window, struct DCC *dcc)
 					                      GDK_INTERP_BILINEAR, 255);
 
 					/* Composite on an emblem which shows the direction of transfer */
-					if (dcc->type == 1)
+					if (dcc->type == 1) {
 						direction_emblem = window->down_icon;
-					else
+					} else {
 						direction_emblem = window->up_icon;
+					}
 
 					gdk_pixbuf_composite (direction_emblem,
 					                      file_icon,
@@ -411,8 +418,10 @@ void
 dcc_window_remove (DccWindow *window, struct DCC *dcc)
 {
 	GtkTreeIter iter;
-	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (window->transfer_store), &iter) == FALSE)
+	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (window->transfer_store), &iter) == FALSE) {
 		return;
+	}
+
 	do {
 		gpointer ptr;
 		gtk_tree_model_get (GTK_TREE_MODEL (window->transfer_store), &iter, DCC_COLUMN, &ptr, -1);
@@ -430,11 +439,11 @@ dcc_send_file (struct User *user)
 	GtkResponseType response;
 
 	dialog = gtk_file_chooser_dialog_new (_("Send File..."),
-			GTK_WINDOW (gui.main_window),
-			GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-			NULL);
+	                GTK_WINDOW (gui.main_window),
+	                GTK_FILE_CHOOSER_ACTION_OPEN,
+	                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+	                NULL);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_hide (dialog);
