@@ -28,8 +28,9 @@
 
 static GtkDialogClass *parent_class;
 
-static gboolean check_input   (IrcNetworkEditor *editor);
-static void     apply_changes (IrcNetworkEditor *editor);
+static gboolean  check_input        (IrcNetworkEditor *editor);
+static void      apply_changes      (IrcNetworkEditor *editor);
+static gchar    *serialize_autojoin (IrcNetworkEditor *editor);
 
 static void
 irc_network_editor_dispose (GObject *object)
@@ -131,8 +132,9 @@ remove_server_clicked (GtkButton *button, IrcNetworkEditor *e)
 	GtkTreeIter iter;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (e->servers));
-	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
 		gtk_list_store_remove (e->server_store, &iter);
+	}
 }
 
 static void
@@ -156,10 +158,11 @@ server_edited (GtkCellRendererText *renderer, gchar *arg1, gchar *newtext, IrcNe
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (e->servers));
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		if (strlen (newtext))
+		if (strlen (newtext)) {
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, newtext, -1);
-		else
+		} else {
 			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+		}
 	}
 }
 
@@ -197,8 +200,9 @@ remove_autojoin_clicked (GtkButton *button, IrcNetworkEditor *e)
 	GtkTreeIter iter;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (e->autojoin_channels));
-	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
 		gtk_list_store_remove (e->autojoin_store, &iter);
+	}
 }
 
 static void
@@ -222,10 +226,11 @@ autojoin_edited (GtkCellRendererText *renderer, gchar *arg1, gchar *newtext, Irc
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (e->autojoin_channels));
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		if (strlen (newtext))
+		if (strlen (newtext)) {
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, newtext, -1);
-		else
+		} else {
 			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+		}
 	}
 }
 
@@ -238,10 +243,11 @@ autojoin_key_edited (GtkCellRendererText *renderer, gchar *arg1, gchar *newtext,
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (e->autojoin_channels));
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		if (strlen (newtext))
+		if (strlen (newtext)) {
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 1, newtext, -1);
-		else
+		} else {
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 1, NULL, -1);
+		}
 	}
 }
 
@@ -251,18 +257,19 @@ irc_network_editor_init (IrcNetworkEditor *dialog)
 	gchar **enc;
 	GtkTreeSelection *server_selection, *autojoin_selection;
 	GladeXML *xml;
+	gchar *path;
 
 	dialog->gconf = NULL;
 	dialog->network = NULL;
 	dialog->toplevel = NULL;
 
 	xml = NULL;
-	if (g_file_test ("../../data/irc-network-editor.glade", G_FILE_TEST_EXISTS))
-		xml = glade_xml_new ("../../data/irc-network-editor.glade", "toplevel", NULL);
-	if (!xml)
-		xml = glade_xml_new (XCHATSHAREDIR "/irc-network-editor.glade", "toplevel", NULL);
-	if (!xml)
+	path = locate_data_file ("irc-network-editor.glade");
+	xml = glade_xml_new (path, "toplevel", NULL);
+	g_free (path);
+	if (!xml) {
 		return;
+	}
 
 #define GW(name) ((dialog->name) = glade_xml_get_widget (xml, #name))
 	GW(network_settings_table);
@@ -403,8 +410,9 @@ populate_autojoin_list (IrcNetworkEditor *e)
 	gint i;
 	gboolean keys_done;
 
-	if (!e->network->autojoin)
+	if (!e->network->autojoin) {
 		return;
+	}
 
 	autojoin = g_strsplit (e->network->autojoin, " ", 0);
 	channels = g_strsplit (autojoin[0], ",", 0);
@@ -479,10 +487,12 @@ irc_network_editor_populate (IrcNetworkEditor *e)
 	gtk_widget_set_sensitive (e->edit_autojoin, FALSE);
 	gtk_widget_set_sensitive (e->remove_autojoin, FALSE);
 
-	if (e->network->password)
+	if (e->network->password) {
 		gtk_entry_set_text (GTK_ENTRY (e->password), e->network->password);
-	if (e->network->nickserv_password)
+	}
+	if (e->network->nickserv_password) {
 		gtk_entry_set_text (GTK_ENTRY (e->nickserv_password), e->network->nickserv_password);
+	}
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (e->encoding), e->network->encoding);
 
@@ -565,26 +575,7 @@ apply_changes (IrcNetworkEditor *e)
 	}
 	channels = t1;
 
-	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (e->autojoin_store), &iter)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (e->autojoin_store), &iter, 1, &t1, -1);
-
-		if (t1 == NULL) {
-			t1 = "";
-		}
-		t1 = g_strdup (t1);
-
-		while (gtk_tree_model_iter_next (GTK_TREE_MODEL (e->autojoin_store), &iter)) {
-			gtk_tree_model_get (GTK_TREE_MODEL (e->autojoin_store), &iter, 1, &t2, -1);
-			if (t2 == NULL) {
-				t2 = "";
-			}
-			t3 = g_strdup_printf ("%s,%s", t1, t2);
-			g_free (t1);
-			t1 = t3;
-		}
-	}
-	net->autojoin = g_strdup_printf ("%s %s", channels, t1);
-	g_free (channels);
+	net->autojoin = serialize_autojoin (e);
 
 	irc_network_save (net);
 }
@@ -623,6 +614,64 @@ check_input (IrcNetworkEditor *editor)
 	return TRUE;
 }
 
+static gchar *
+serialize_autojoin (IrcNetworkEditor *editor)
+{
+	gchar *channels  = NULL;
+	gchar *passwords = NULL;
+	gchar *channel;
+	gchar *password;
+	gchar *ret;
+	GtkTreeIter iter;
+
+	// We run through the store twice.  On the first pass, we only get
+	// servers that have passwords set.  On the second, we do the rest.
+	// This is because xchat wants this order.
+	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (editor->autojoin_store), &iter)) {
+		do {
+			gtk_tree_model_get (GTK_TREE_MODEL (editor->autojoin_store), &iter, 0, &channel, 1, &password, -1);
+			if (password) {
+				if (channels) {
+					gchar *tmp = g_strdup_printf ("%s,%s", channels, channel);
+					g_free (channels);
+					channels = tmp;
+
+					tmp = g_strdup_printf ("%s,%s", passwords, password);
+					g_free (passwords);
+					passwords = tmp;
+				} else {
+					channels = g_strdup (channel);
+					passwords = g_strdup (password);
+				}
+			}
+		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (editor->autojoin_store), &iter));
+	}
+
+	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (editor->autojoin_store), &iter)) {
+		do {
+			gtk_tree_model_get (GTK_TREE_MODEL (editor->autojoin_store), &iter, 0, &channel, 1, &password, -1);
+			if (password == NULL) {
+				if (channels) {
+					gchar *tmp = g_strdup_printf ("%s,%s", channels, channel);
+					g_free (channels);
+					channels = tmp;
+				} else {
+					channels = g_strdup (channel);
+				}
+			}
+		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (editor->autojoin_store), &iter));
+	}
+
+	if (passwords) {
+		ret = g_strdup_printf ("%s %s", channels, passwords);
+		g_free (channels);
+		g_free (passwords);
+		return ret;
+	} else {
+		return channels;
+	}
+}
+
 void
 irc_network_editor_run (IrcNetworkEditor *editor)
 {
