@@ -78,8 +78,9 @@ edit_clicked (GtkWidget *button, PreferencesNetworksPage *page)
 	GtkTreeIter iter;
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (page->network_list));
-	if (!gtk_tree_selection_get_selected (select, &model, &iter))
+	if (!gtk_tree_selection_get_selected (select, &model, &iter)) {
 		return;
+	}
 	gtk_tree_model_get (model, &iter, 1, &net, -1);
 
 	n = irc_network_new (net);
@@ -94,8 +95,9 @@ static void
 edit_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, PreferencesNetworksPage *page)
 {
 	GtkTreeIter iter;
-	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (page->sort_model), &iter, path))
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (page->sort_model), &iter, path)) {
 		edit_clicked (NULL, page);
+	}
 }
 
 static void
@@ -109,8 +111,9 @@ remove_clicked (GtkWidget *button, PreferencesNetworksPage *page)
 	gint r;
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (page->network_list));
-	if (!gtk_tree_selection_get_selected (select, &model, &iter))
+	if (!gtk_tree_selection_get_selected (select, &model, &iter)) {
 		return;
+	}
 	gtk_tree_model_get(model, &iter, 1, &net, -1);
 
 	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, _("Really remove network \"%s\" and all of its servers?"), net->name);
@@ -150,6 +153,7 @@ preferences_page_networks_new (gpointer prefs_dialog, GladeXML *xml)
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select;
+	gchar *path;
 
 #define GW(name) ((page->name) = glade_xml_get_widget (xml, #name))
 	GW(network_list);
@@ -161,10 +165,10 @@ preferences_page_networks_new (gpointer prefs_dialog, GladeXML *xml)
 	gtk_widget_set_sensitive (page->network_edit, FALSE);
 	gtk_widget_set_sensitive (page->network_remove, FALSE);
 
-	if (g_file_test ("../../data/servers.png", G_FILE_TEST_EXISTS))
-		page->icon = gdk_pixbuf_new_from_file ("../../data/servers.png", NULL);
-	else
-		page->icon = gdk_pixbuf_new_from_file (XCHATSHAREDIR "/servers.png", NULL);
+	path = locate_data_file ("servers.png");
+	page->icon = gdk_pixbuf_new_from_file (path, NULL);
+	g_free (path);
+
 	gtk_list_store_append (p->page_store, &iter);
 	gtk_list_store_set (p->page_store, &iter, 0, page->icon, 1, _("Networks"), 2, 4, -1);
 
